
MRI Reconstruction Toolbox in PyTorch
_____________________________________


.. installation-section-start

Installation
------------
`MRI Reconstruction Toolbox in PyTorch  <https://github.com/denproc/mrirecon>`_ can be installed using ``pip`` or ``git``.


If you use ``pip``, you can install it with:

.. code-block:: sh

    $ pip install mrirecon

If you want to use the latest features straight from the master, clone `MRI Reconstruction repo <https://github.com/denproc/mrirecon>`_:

.. code-block:: sh

   git clone https://github.com/denproc/mrirecon.git
   cd piq
   python setup.py install

.. installation-section-end

.. citation-section-start

Citation
--------
If you use  in your project, please, cite it as follows.

.. code-block:: tex

   @misc{mrirecon,
     title={MRI Reconstruction Toolbox in PyTorch},
     url={https://github.com/denproc/mrirecon},
     note={Open-source software available at https://github.com/denproc/mrirecon},
     author={Denis Prokopenko},
     year={2022},
   }

.. citation-section-end

.. contacts-section-start

Contacts
--------
**Denis Prokopenko** - `@denproc <https://github.com/denproc>`_ - ``d.prokopenko@outlook.com``

.. contacts-section-end